/**

  The Initial Developer of the Original Code is
  Matthieu  - http://www.programmation-facile.com/
  Portions created by the Initial Developer are Copyright (C) 2013
  the Initial Developer. All Rights Reserved.

  Contributor(s) :

 */



/**
 * Le Framework de jeux JavaScript Phaser
 *
Phaser v2.0.5 - http://phaser.io - @photonstorm - (c) 2014 Photon Storm Ltd. 
https://github.com/photonstorm/phaser
http://examples.phaser.io/
 */



/**
 * Les variables du jeu
 * 
 */
var game; 

var nWidth = 480;
var nHeight = 320;


// les variables du jeu
var playerSpeed = 150;// vitesse de déplacement du joueur
var player;// le joueur
var platformGroup;// les plateformes



document.addEventListener("DOMContentLoaded", Main, false); // appel au chargement de la page



/**
 * Fonction principale
 * Appelée au chargement de la page
 * 
 */
function Main()
{
    console.log("Main");

    // creation de la zone de jeu - API canvas
    game = new Phaser.Game(nWidth, nHeight, Phaser.AUTO, "idGameDiv", {preload:onPreload, create:onCreate, update:onUpdate});

    // les variables globales du jeu
    game.global = {
        thumbRows : 5// nombre d'icone par ligne  game.global.thumbRows
    }

}


/**
 * Préchargement des éléments du jeu
 * 
 * @return {[type]} [description]
 */
function onPreload()
{ 
    // charge les animations / graphismes du jeu
    game.load.image("platform180","assets/platform180.png");
    game.load.image("platform120","assets/platform120.png");
    game.load.image("player","assets/player.png");
    game.load.image("ground","assets/ground.png");
    game.stage.backgroundColor = '#cccccc';// la couleur de fond du jeu
}



/**
 * Création de la scène du jeu,
 * mise en place des graphismes...
 * 
 * @return {[type]} [description]
 */
function onCreate() 
{
    // création d'un groupe qui contient toutes les plateformes
    platformgroup = game.add.group();

    // ajout de la gestion des collisions
    game.physics.startSystem(Phaser.Physics.ARCADE);

    // création du joueur
    player = game.add.sprite(240, 0, "player");
    player.anchor.setTo(0.5);

   
    game.physics.enable(player, Phaser.Physics.ARCADE);// gestion des collisions avec le joueur
    game.physics.arcade.gravity.y = playerSpeed;// défini la vitesse de déplacement du joueur en horizontal

    // construction du niveau
    addPlatform(240,60,"platform180");  
    addPlatform(120,100,"platform120");  
    addPlatform(360,100,"platform120");  
    addPlatform(95,160,"platform120");
    addPlatform(300,160,"platform120");
    addPlatform(420,220,"platform120"); 
    addPlatform(60,220,"platform120");
    addPlatform(100,316,"ground");
    addPlatform(380,316,"ground");

    // écouteur sur le clic de la souris
    game.input.onDown.add(changeDir, this); 
}


/**
 * Appelée en continu pendant le jeu
 * 
 * @return {[type]} [description]
 */
function onUpdate() 
{
    // déplacement du joueur
    player.body.velocity.y = Math.abs(playerSpeed);
    player.body.velocity.x = 0;
    
    // gestion des collisions entre le joueur et les plateformes - appel la fonction movePlayer
    game.physics.arcade.collide(player, platformgroup, movePlayer);


    // le joueur tombe en bas du jeu
    if(player.y>nHeight)
        player.y = 0;// positionne le joueur en haut ou game over...
    

    // le joueur touche le bord gauche
    if( player.x < (player.width/2) )
    {
        player.x= player.width/2;
        playerSpeed*=-1;// inverse la direction du joueur
    }


    // le joueur touche le bord droit
    if( player.x > (nWidth-player.width/2) )
    {
        player.x= nWidth-player.width/2;
        playerSpeed*=-1;// inverse la direction du joueur
    }
}


/**
 * Création des plateformes du jeu
 * 
 * @param {[type]} posX  [description]
 * @param {[type]} posY  [description]
 * @param {[type]} asset [description]
 */
function addPlatform(posX,posY,asset)
{
    platform = game.add.sprite(posX,posY,asset)
    platform.anchor.setTo(0.5);

    // gestion des collissions et gravité
    game.physics.enable(platform, Phaser.Physics.ARCADE);
    platform.body.allowGravity = false;
    platform.body.immovable = true;

    platformgroup.add(platform);    
}


/**
 * Déplacement du joueur
 * (possibilité d'ajouter une gestion du clavier)
 * 
 * @return {[type]} [description]
 */
function movePlayer()
{     
    player.body.velocity.x = playerSpeed;
}


/**
 * Change la direction de déplacement du joueur
 * 
 * @return {[type]} [description]
 */
function changeDir()
{
    playerSpeed *= -1;
}



